@@ -1579,6 +1579,7 @@ class NiceEventTreasureBox(BaseModelORJson):
     maxDrawNumOnce: int
     extraGifts: list[NiceGift]
     commonConsume: NiceCommonConsume
+    consumes: list[NiceCommonConsume]
 
 
 class NiceEventDiggingBlock(BaseModelORJson):
@@ -1586,6 +1587,7 @@ class NiceEventDiggingBlock(BaseModelORJson):
     eventId: int
     image: HttpUrl
     commonConsume: NiceCommonConsume
+    consumes: list[NiceCommonConsume]
     objectId: int
     diggingEventPoint: int
     blockNum: int
@@ -1613,6 +1615,7 @@ class NiceEventCooltimeReward(BaseModelORJson):
     lv: int
     name: str
     commonRelease: NiceCommonRelease
+    releaseConditions: list[NiceCommonRelease]
     cooltime: int
     addEventPointRate: int
     gifts: list[NiceGift]
@@ -1637,6 +1640,26 @@ class NiceEventBulletinBoard(BaseModelORJson):
     releaseConditions: list[NiceEventBulletinBoardRelease]
 
 
+class NiceEventRecipeGift(BaseModelORJson):
+    idx: int
+    displayOrder: int
+    topIconId: int
+    gifts: list[NiceGift]
+
+
+class NiceEventRecipe(BaseModelORJson):
+    id: int
+    icon: HttpUrl
+    name: str
+    maxNum: int
+    eventPointItem: NiceItem
+    eventPointNum: int
+    consumes: list[NiceCommonConsume]
+    releaseConditions: list[NiceCommonRelease]
+    closedMessage: str
+    recipeGifts: list[NiceEventRecipeGift]
+
+
 class NiceEventRewardSceneGuide(BaseModelORJson):
     imageId: int
     limitCount: int
@@ -1702,6 +1725,7 @@ class NiceEvent(BaseModelORJson):
     lotteries: list[NiceEventLottery]
     treasureBoxes: list[NiceEventTreasureBox]
     bulletinBoards: list[NiceEventBulletinBoard]
+    recipes: list[NiceEventRecipe]
     digging: NiceEventDigging | None
     cooltime: NiceEventCooltime | None
     voicePlays: list[NiceEventVoicePlay]
@@ -1797,7 +1821,7 @@ class EnemyScript(BaseModelORJson):
     call: Optional[list[int]] = Field(None, title="Summon these NPC IDs")
     shift: Optional[list[int]] = Field(None, title="Break bar switch to these NPC IDs")
     shiftPosition: Optional[int]
-    shiftClear: list[NiceTrait] = Field(
+    shiftClear: list[NiceTrait] | None = Field(
         None, title="Active buff traits to remove with break bar"
     )
     skillShift: Optional[list[int]]
